@@ -1,5 +1,6 @@
 # encoding: utf-8
 
+import re
 import time
 import socket
 import logging_helper
@@ -11,6 +12,8 @@ logging = logging_helper.setup_logging()
 
 class JumpBox(Observable):
 
+    ANSI_ESCAPE = re.compile(r'\x1B\[[0-?]*[ -/]*[@-~]')  # https://stackoverflow.com/a/14693789/2916546
+
     def __init__(self,
                  host,
                  username,
@@ -30,7 +33,7 @@ class JumpBox(Observable):
         self.log = log
 
         self.prompts = [u'~]$ ',
-                        u'-bash-3.2$ '] + prompts if prompts is not None else []
+                        u'-bash-3.2$ '] + (prompts if prompts is not None else [])
 
         self.command_width = 80  # Set to default size when invoke_shell() is run!
 
@@ -65,6 +68,7 @@ class JumpBox(Observable):
         while not self.buffer.endswith(tuple(self.prompts)):
             if self.shell.recv_ready():
                 self.buffer += self.shell.recv(1024)
+                logging.info(self.buffer)
 
             if not self.buffer.endswith(tuple(self.prompts)):
                 if timeout == 0:
@@ -243,18 +247,29 @@ class JumpBox(Observable):
 
         return resp, status
 
+    def __strip_ansi(self):
+        self.buffer = self.ANSI_ESCAPE.sub('', self.buffer)
+
     def __receive(self, timeout):
 
+        TERMINATION_TIMEOUT = 10  # Arbitrary extra time for termination
+
         self.buffer = u''
-        while not self.buffer.endswith(tuple(self.prompts)):
+        while not self.buffer.endswith(tuple(self.prompts)) and -TERMINATION_TIMEOUT < timeout:
 
             if timeout == 0:
                 logging.warning(u'Timeout exceeded, terminating command!')
                 self.shell.send("\x03")
                 self.shell.send("\n")
 
+                logging_helper.LogLines(lines="Received:"+self.buffer)
+                logging_helper.LogLines(lines=["Expected prompt:"]+self.prompts)
+
             if self.shell.recv_ready():
-                self.buffer += self.shell.recv(1024)
+                recv = self.shell.recv(1024)
+                self.buffer = self.ANSI_ESCAPE.sub('', self.buffer + recv)
+                logging_helper.LogLines(lines=recv,
+                                        level=logging_helper.DEBUG)
 
             if self.buffer.endswith(u'Are you sure you want to continue connecting (yes/no)? '):
                 self.command(command=u'yes')
