@@ -59,12 +59,14 @@ class SFTPHelper(object):
             return
         try:
             self.private_key = paramiko.RSAKey.from_private_key(file_obj=StringIO(private_key))
+            logging.debug("private key resolved")
             return
         except (IOError, paramiko.ssh_exception.SSHException):
             pass
 
         try:
             self.private_key = paramiko.RSAKey.from_private_key_file(filename=private_key)
+            logging.debug("private key resolved")
             return
         except IOError:
             pass
@@ -82,6 +84,7 @@ class SFTPHelper(object):
                       u'python/example/7445/paramiko.Transport\n'
                       u'for some ideas on how to do that!')
         else:
+            logging.debug("host key resolved.")
             self.host_key = host_key
 
     def connect(self):
